Class: Astronoby::Earth

Inherits:
SolarSystemBody show all
Defined in:
lib/astronoby/bodies/earth.rb

Overview

Represents the Earth. Provides ephemeris segments for computing Earth’s geometric position.

Constant Summary collapse

ORBITAL_PERIOD =
365.256

Constants inherited from SolarSystemBody

SolarSystemBody::EARTH, SolarSystemBody::EARTH_MOON_BARYCENTER, SolarSystemBody::JUPITER_BARYCENTER, SolarSystemBody::MARS_BARYCENTER, SolarSystemBody::MERCURY, SolarSystemBody::MERCURY_BARYCENTER, SolarSystemBody::MOON, SolarSystemBody::NEPTUNE_BARYCENTER, SolarSystemBody::SATURN_BARYCENTER, SolarSystemBody::SOLAR_SYSTEM_BARYCENTER, SolarSystemBody::SUN, SolarSystemBody::URANUS_BARYCENTER, SolarSystemBody::VENUS, SolarSystemBody::VENUS_BARYCENTER

Instance Attribute Summary

Attributes inherited from SolarSystemBody

#ephem, #instant, #orientation

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from SolarSystemBody

absolute_magnitude, #angular_diameter, #apparent, #apparent_magnitude, #approaching_primary?, #astrometric, at, #body, compute_geometric, conjunction_events, #constellation, #earth_geometric, #eastern?, #elongation, geometric, #geometric, greatest_elongation_events, #illuminated_fraction, inferior_planet?, #initialize, #mean_of_date, opposition_events, planet?, #receding_from_primary?, rise_transit_set_events, superior_planet?, #western?

Methods included from Position

#observed_by

Constructor Details

This class inherits a constructor from Astronoby::SolarSystemBody

Class Method Details

.ephemeris_segments(ephem_source) ⇒ Array<Array>

Returns ephemeris segment identifiers.

Parameters:

  • ephem_source (Symbol)

    the ephemeris source type

Returns:

  • (Array<Array>)

    ephemeris segment identifiers



11
12
13
14
15
16
17
18
19
20
21
22
# File 'lib/astronoby/bodies/earth.rb', line 11

def self.ephemeris_segments(ephem_source)
  if ephem_source == ::Ephem::SPK::JPL_DE
    [
      [SOLAR_SYSTEM_BARYCENTER, EARTH_MOON_BARYCENTER],
      [EARTH_MOON_BARYCENTER, EARTH]
    ]
  elsif ephem_source == ::Ephem::SPK::INPOP
    [
      [SOLAR_SYSTEM_BARYCENTER, EARTH]
    ]
  end
end

Instance Method Details

#phase_anglenil

Returns Earth has no phase angle as seen from itself.

Returns:

  • (nil)

    Earth has no phase angle as seen from itself



25
26
27
# File 'lib/astronoby/bodies/earth.rb', line 25

def phase_angle
  nil
end