Class: Astronoby::Astrometric
- Inherits:
-
ReferenceFrame
- Object
- ReferenceFrame
- Astronoby::Astrometric
- Defined in:
- lib/astronoby/reference_frames/astrometric.rb
Overview
Astrometric reference frame (GCRS). Represents a body’s position relative to the Earth, corrected for light-time delay.
Instance Attribute Summary
Attributes inherited from ReferenceFrame
#center, #instant, #position, #target_body, #velocity
Class Method Summary collapse
-
.build_from_geometric(instant:, earth_geometric:, light_time_corrected_position:, light_time_corrected_velocity:, target_body:) ⇒ Astronoby::Astrometric
Builds an astrometric frame from geometric frames with light-time correction.
Methods inherited from ReferenceFrame
#distance, #ecliptic, #equatorial, #initialize, #separation_from
Constructor Details
This class inherits a constructor from Astronoby::ReferenceFrame
Class Method Details
.build_from_geometric(instant:, earth_geometric:, light_time_corrected_position:, light_time_corrected_velocity:, target_body:) ⇒ Astronoby::Astrometric
Builds an astrometric frame from geometric frames with light-time correction.
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/astronoby/reference_frames/astrometric.rb', line 18 def self.build_from_geometric( instant:, earth_geometric:, light_time_corrected_position:, light_time_corrected_velocity:, target_body: ) new( position: light_time_corrected_position - earth_geometric.position, velocity: light_time_corrected_velocity - earth_geometric.velocity, instant: instant, center: Center.geocentric, target_body: target_body ) end |